@@ -20,10 +20,9 @@ import logging
 import os
 import sys
 
-from debtcollector import removals
 from django.core.management import color_style
 from django.utils import encoding
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.views.debug import SafeExceptionReporterFilter
 
 from horizon.conf import HORIZON_CONFIG
@@ -192,22 +191,6 @@ def error_color(msg):
     return color_style().ERROR_OUTPUT(msg)
 
 
-@removals.remove(message='Use exceptions.handle() instead', version='17.2.0')
-def check_message(keywords, message):
-    """Checks an exception for given keywords and raises an error if found.
-
-    It raises a new ``ActionError`` with the desired message if the
-    keywords are found. This allows selective
-    control over API error messages.
-    """
-    exc_type, exc_value, exc_traceback = sys.exc_info()
-    if set(str(exc_value).split(" ")).issuperset(set(keywords)):
-        exc_value.message = message
-        # NOTE: This function is intended to call inside an except clause.
-        # pylint: disable=misplaced-bare-raise
-        raise
-
-
 def handle_unauthorized(request, message, redirect, ignore, escalate, handled,
                         force_silence, force_log,
                         log_method, log_entry, log_level):
@@ -263,8 +246,8 @@ HANDLE_EXC_METHODS = [
 
 
 def _append_detail(message, details):
-    return encoding.force_text(message) + SEPARATOR + \
-        encoding.force_text(details)
+    return encoding.force_str(message) + SEPARATOR + \
+        encoding.force_str(details)
 
 
 def handle(request, message=None, redirect=None, ignore=False,
@@ -315,7 +298,7 @@ def handle(request, message=None, redirect=None, ignore=False,
         exc_type, exc_value, exc_traceback = exc_value.wrapped
         wrap = True
 
-    log_entry = encoding.force_text(exc_value)
+    log_entry = encoding.force_str(exc_value)
 
     user_message = ""
     # We trust messages from our own exceptions
@@ -323,9 +306,9 @@ def handle(request, message=None, redirect=None, ignore=False,
         user_message = log_entry
     # If the message has a placeholder for the exception, fill it in
     elif message and "%(exc)s" in message:
-        user_message = encoding.force_text(message) % {"exc": log_entry}
+        user_message = encoding.force_str(message) % {"exc": log_entry}
     elif message:
-        user_message = encoding.force_text(message)
+        user_message = encoding.force_str(message)
     if details is None:
         user_message = _append_detail(user_message, exc_value)
     elif details:
