@@ -11,12 +11,11 @@
 # under the License.
 
 import glob
-from optparse import make_option  # noqa
+from importlib import import_module
 import os
 
-from django.core.management.base import CommandError  # noqa
-from django.core.management.templates import TemplateCommand  # noqa
-from importlib import import_module
+from django.core.management.base import CommandError
+from django.core.management.templates import TemplateCommand
 
 import horizon
 
@@ -70,6 +69,7 @@ class Command(TemplateCommand):
 
         target = options.pop("target", None)
         if target == "auto":
+            # pylint: disable-next=possibly-used-before-assignment
             target = os.path.join(os.path.dirname(dashboard_mod.__file__),
                                   panel_name)
             if not os.path.exists(target):
@@ -93,7 +93,7 @@ class Command(TemplateCommand):
                                "Python module and cannot be used as an app "
                                "name. Please try another name." % panel_name)
 
-        super(Command, self).handle('panel', panel_name, target, **options)
+        super().handle('panel', panel_name, target, **options)
 
         if not target:
             target = os.path.join(os.curdir, panel_name)
