@@ -19,20 +19,23 @@
     .module('horizon.framework.widgets.modal-wait-spinner')
     .factory('horizon.framework.widgets.modal-wait-spinner.service', WaitSpinnerService);
 
-  WaitSpinnerService.$inject = ['$uibModal'];
+  WaitSpinnerService.$inject = [
+    '$interpolate',
+    '$templateCache',
+    'horizon.framework.widgets.basePath',
+    '$uibModal'
+  ];
 
   /*
    * @ngdoc factory
    * @name horizon.framework.widgets.modal-wait-spinner.factory:WaitSpinnerService
    * @description
    * In order to provide a seamless transition to a Horizon that uses more Angular
-   * based pages, the service is currently implemented using the existing
-   * Spin.js library and the corresponding jQuery plugin (jquery.spin.js). This widget
-   * looks and feels the same as the existing spinner we are familiar with in Horizon.
-   * Over time, uses of the existing Horizon spinner ( horizon.modals.modal_spinner() )
-   * can be phased out, or refactored to use this component.
+   * based pages, the service is currently implemented using the same markup as the
+   * client side loader, which is composed of HTML and a spinner Icon Font.
    */
-  function WaitSpinnerService ($uibModal) {
+
+  function WaitSpinnerService ($interpolate, $templateCache, basePath, $uibModal) {
     var spinner = this;
     var service = {
       showModalSpinner: showModalSpinner,
@@ -44,15 +47,12 @@
     ////////////////////
 
     function showModalSpinner(spinnerText) {
+      var templateUrl = basePath + 'modal-wait-spinner/modal-wait-spinner.template.html';
+      var html = $templateCache.get(templateUrl);
       var modalOptions = {
         backdrop: 'static',
-        /*
-         * Using <div> for wait-spinner instead of a wait-spinner element
-         * because the existing Horizon spinner CSS styling expects a div
-         * for the modal-body
-         */
-        template: '<div wait-spinner class="modal-body" text="' + spinnerText + '"></div>',
-        windowClass: 'modal-wait-spinner modal_wrapper loading'
+        template: $interpolate(html)({text: spinnerText}),
+        windowClass: 'modal-wait-spinner'
       };
       spinner.modalInstance = $uibModal.open(modalOptions);
     }
