@@ -14,10 +14,10 @@
 """API for the swift service."""
 
 import os
+from urllib import parse
 
 from django import forms
 from django.http import StreamingHttpResponse
-from django.utils.http import urlunquote
 from django.views.decorators.csrf import csrf_exempt
 from django.views import generic
 
@@ -148,7 +148,7 @@ class Objects(generic.View):
         """
         path = request.GET.get('path')
         if path is not None:
-            path = urlunquote(path)
+            path = parse.unquote(path)
 
         objects = api.swift.swift_get_objects(
             request,
@@ -252,7 +252,8 @@ class Object(generic.View):
         safe = filename.replace(",", "")
         response['Content-Disposition'] = 'attachment; filename="%s"' % safe
         response['Content-Type'] = 'application/octet-stream'
-        response['Content-Length'] = obj.bytes
+        if obj.bytes is not None:
+            response['Content-Length'] = obj.bytes
         return response
 
 
