@@ -13,8 +13,8 @@
 from urllib import parse
 
 from django.urls import reverse
-from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import ungettext_lazy
+from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ngettext_lazy
 
 from horizon import tables
 
@@ -25,7 +25,7 @@ class GroupTypeSpecDelete(tables.DeleteAction):
 
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             "Delete Spec",
             "Delete Specs",
             count
@@ -33,7 +33,7 @@ class GroupTypeSpecDelete(tables.DeleteAction):
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             "Delete Spec",
             "Delete Specs",
             count
