@@ -13,8 +13,8 @@
 #    under the License.
 
 from django.template import defaultfilters as filters
-from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import ungettext_lazy
+from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ngettext_lazy
 
 from horizon import forms
 from horizon import tables
@@ -43,7 +43,7 @@ class EditNamespace(tables.LinkAction):
 class DeleteNamespace(tables.DeleteAction):
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             "Delete Namespace",
             "Delete Namespaces",
             count
@@ -51,7 +51,7 @@ class DeleteNamespace(tables.DeleteAction):
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             "Deleted Namespace",
             "Deleted Namespaces",
             count
