@@ -10,9 +10,9 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from django.urls import reverse
+from unittest import mock
 
-import mock
+from django.urls import reverse
 
 from openstack_dashboard import api
 from openstack_dashboard.dashboards.admin.volume_types.qos_specs \
