@@ -14,9 +14,7 @@
 
 from django.conf import settings
 from django.template.defaultfilters import title
-from django.utils.translation import ugettext_lazy as _
-
-from openstack_auth import utils
+from django.utils.translation import gettext_lazy as _
 
 from horizon import tables
 from openstack_dashboard import api
@@ -62,28 +60,8 @@ class DownloadOpenRC(tables.LinkAction):
     icon = "download"
     url = "horizon:project:api_access:openrc"
 
-    def __init__(self, attrs=None, **kwargs):
-        super(DownloadOpenRC, self).__init__(attrs, **kwargs)
-        # When keystone v2 RC file is enabled, we need to show
-        # the version information of keystone API.
-        # Note that we don't need to care verbose_name_plural here.
-        if getattr(settings, 'SHOW_KEYSTONE_V2_RC', False):
-            self.verbose_name = _("OpenStack RC File (Identity API v3)")
-
     def allowed(self, request, datum=None):
-        return (settings.SHOW_OPENRC_FILE and
-                utils.get_keystone_version() >= 3)
-
-
-class DownloadOpenRCv2(tables.LinkAction):
-    name = "download_openrc_v2"
-    verbose_name = _("OpenStack RC File (Identity API v2.0)")
-    verbose_name_plural = _("OpenStack RC File (Identity API v2.0)")
-    icon = "download"
-    url = "horizon:project:api_access:openrcv2"
-
-    def allowed(self, request, datum=None):
-        return settings.SHOW_KEYSTONE_V2_RC
+        return settings.SHOW_OPENRC_FILE
 
 
 class ViewCredentials(tables.LinkAction):
@@ -130,7 +108,6 @@ class EndpointsTable(tables.DataTable):
         multi_select = False
         table_actions = (ViewCredentials, RecreateCredentials)
         table_actions_menu = (DownloadCloudsYaml,
-                              DownloadOpenRCv2,
                               DownloadOpenRC,
                               DownloadEC2)
         table_actions_menu_label = _('Download OpenStack RC File')
