@@ -22,7 +22,7 @@ from django import http
 from django import shortcuts
 from django.template.loader import render_to_string
 from django.urls import reverse_lazy
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from horizon import exceptions
 from horizon import forms
@@ -100,6 +100,7 @@ def download_ec2_bundle(request):
     # Create our file bundle
     template = 'project/api_access/ec2rc.sh.template'
     try:
+        # pylint: disable-next=consider-using-with
         temp_zip = tempfile.NamedTemporaryFile(delete=True)
         with closing(zipfile.ZipFile(temp_zip.name, mode='w')) as archive:
             archive.writestr('ec2rc.sh', render_to_string(template, context))
