@@ -22,7 +22,7 @@ from django.conf import settings
 from django.http import HttpResponse
 from django.urls import reverse
 from django.urls import reverse_lazy
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.views.generic import View
 
 from horizon import exceptions
@@ -49,8 +49,6 @@ from openstack_dashboard.dashboards.project.instances.tables import \
     STATUS_DISPLAY_CHOICES as instance_choices
 from openstack_dashboard.dashboards.project.instances import\
     views as i_views
-from openstack_dashboard.dashboards.project.instances.workflows import\
-    create_instance as i_workflows
 from openstack_dashboard.dashboards.project.networks.subnets import\
     views as s_views
 from openstack_dashboard.dashboards.project.networks.subnets import\
@@ -139,14 +137,6 @@ class NTCreateNetworkView(n_views.CreateView):
     workflow_class = NTCreateNetwork
 
 
-class NTLaunchInstance(i_workflows.LaunchInstance):
-    success_url = "horizon:project:network_topology:index"
-
-
-class NTLaunchInstanceView(i_views.LaunchInstanceView):
-    workflow_class = NTLaunchInstance
-
-
 class NTCreateSubnet(s_workflows.CreateSubnet):
     def get_success_url(self):
         return reverse("horizon:project:network_topology:index")
@@ -294,7 +284,7 @@ class JSONView(View):
                    'status': self.trans.network[network.status],
                    'allow_delete_subnet': allow_delete_subnet,
                    'original_status': network.status,
-                   'router:external': network['router:external']}
+                   'router:external': network['is_router_external']}
             self.add_resource_url('horizon:project:networks:subnets:detail',
                                   obj['subnets'])
             networks.append(obj)
@@ -325,7 +315,7 @@ class JSONView(View):
                     'subnets': subnets,
                     'status': self.trans.network[publicnet.status],
                     'original_status': publicnet.status,
-                    'router:external': publicnet['router:external']})
+                    'router:external': publicnet['is_router_external']})
 
         self.add_resource_url('horizon:project:networks:detail',
                               networks)
