@@ -12,12 +12,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf.urls import patterns
-from django.conf.urls import url
+from django.urls import re_path
 
 from openstack_dashboard.dashboards.settings.user import views
 
 
-urlpatterns = patterns(
-    '',
-    url(r'^$', views.UserSettingsView.as_view(), name='index'))
+urlpatterns = [
+    re_path(r'^$', views.UserSettingsView.as_view(), name='index'),
+]
