@@ -6,4 +6,5 @@ PANEL_DASHBOARD = 'project'
 PANEL_GROUP = 'volumes'
 
 # Python panel class of the PANEL to be added.
-ADD_PANEL = 'openstack_dashboard.dashboards.project.volume_groups.panel.VolumeGroups'
+ADD_PANEL = ('openstack_dashboard.dashboards.project.volume_groups.panel.'
+             'VolumeGroups')
