@@ -28,10 +28,18 @@
       userSession = {get: angular.noop};
       $provide.value('horizon.app.core.openstack-service-api.userSession', userSession);
       deferred = {promise: angular.noop, reject: angular.noop, resolve: angular.noop};
-      q = {all: function() {return {then: angular.noop};},
-           defer: function() { return deferred;}};
+      q = {
+        all: function() {
+          return {then: angular.noop};
+        },
+        defer: function() {
+          return deferred;
+        }
+      };
       $provide.value('$q', q);
-      $provide.value('$cacheFactory', function() { return 'cache'; });
+      $provide.value('$cacheFactory', function() {
+        return 'cache';
+      });
     }));
 
     beforeEach(
