@@ -96,6 +96,9 @@ NetworkGroup = [
         # can be changed as per available external network.
         default='public',
         help='The external network for a router creation.'),
+    cfg.StrOpt('subnet_name',
+               default='public-subnet',
+               help='Default public network subnet name'),
 ]
 
 AvailableServiceGroup = [
@@ -189,6 +192,56 @@ PluginGroup = [
         help=('JSON string to define the page structure for the plugin')),
 ]
 
+ThemeGroup = [
+    cfg.StrOpt('project_name_xpath',
+               default='.//*[@class="context-project"]',
+               help='Default xpath for project name dropdown button'),
+    cfg.ListOpt('help_sequence',
+                default=['.//*[@class="dropdown user-menu"]',
+                         './/*[normalize-space()="Help"]'],
+                help='Default steps for redirect to help URL'),
+    cfg.BoolOpt('test_material_theme',
+                default=True,
+                help='Set to False to disallow running the material '
+                     'theme test'),
+    cfg.StrOpt('user_name_xpath',
+               default='.//*[@class="dropdown user-menu"]',
+               help='Default xpath for user name dropdown button'),
+    cfg.ListOpt('browse_left_panel_main',
+                default=['Project', 'Project', 'Project', 'Project',
+                         'Project', 'Project', 'Project', 'Project',
+                         'Project', 'Project', 'Project', 'Project',
+                         'Project', 'Project', 'Project', 'Project',
+                         'Admin', 'Admin', 'Admin', 'Admin', 'Admin',
+                         'Admin', 'Admin', 'Admin', 'Admin', 'Admin',
+                         'Admin', 'Admin', 'Admin', 'Admin', 'Admin',
+                         'Admin', 'Admin', 'Admin', 'Identity', 'Identity',
+                         'Identity', 'Identity', 'Identity'],
+                help='Main buttons for left browse panel'),
+    cfg.ListOpt('browse_left_panel_sec',
+                default=['None', 'Compute', 'Compute', 'Compute', 'Compute',
+                         'Compute', 'Volumes', 'Volumes', 'Network',
+                         'Network', 'Network', 'Network', 'Network',
+                         'Network', 'Network', 'Object store', 'None',
+                         'Compute', 'Compute', 'Compute', 'Compute', 'Compute',
+                         'Volume', 'Volume', 'Volume', 'Volume', 'Network',
+                         'Network', 'Network', 'Network', 'Network', 'Admin',
+                         'Admin', 'Admin', 'None', 'None', 'None', 'None',
+                         'None'],
+                help='Secondary buttons for left browse panel'),
+    cfg.StrOpt('b_l_p_sec_line_xpath',
+               default='.//*[@id="sidebar-accordion-{main_panel}"]',
+               help='Default xpath for first dropdown of browse panel'),
+    cfg.StrOpt('b_l_p_sec_line_req_btn',
+               default='.//a[@data-target='
+               '"#sidebar-accordion-{main_panel}-{sec_panel}"]',
+               help='Default xpath for button for open second dropdown of '
+               'left browse panel'),
+    cfg.StrOpt('b_l_p_sidebar_xpath',
+               default='.//*[@id="sidebar-accordion-{main_panel}-{sec_panel}"]',
+               help='Default xpath for second dropdown of browse panel'),
+]
+
 
 def _get_config_files():
     conf_dir = os.path.join(
@@ -216,6 +269,7 @@ def get_config():
     cfg.CONF.register_opts(InstancesGroup, group="launch_instances")
     cfg.CONF.register_opts(PluginGroup, group="plugin")
     cfg.CONF.register_opts(VolumeGroup, group="volume")
+    cfg.CONF.register_opts(ThemeGroup, group="theme")
 
     return cfg.CONF
 
@@ -233,4 +287,5 @@ def list_opts():
         ("launch_instances", InstancesGroup),
         ("plugin", PluginGroup),
         ("volume", VolumeGroup),
+        ("theme", ThemeGroup),
     ]
