@@ -22,6 +22,7 @@ import xvfbwrapper
 
 from horizon.test import webdriver
 from openstack_dashboard.test.integration_tests import config as horizon_config
+from openstack_dashboard.test.selenium import widgets
 
 
 STASH_FAILED = pytest.StashKey[bool]()
@@ -44,6 +45,7 @@ class Session:
                 config.identity.admin_home_project,
             ),
         }
+        self.project_name_xpath = config.theme.project_name_xpath
         self.logout_url = '/'.join((
             config.dashboard.dashboard_url,
             'auth',
@@ -61,20 +63,20 @@ class Session:
             pass_field = self.driver.find_element_by_id('id_password')
             pass_field.send_keys(password)
             button = self.driver.find_element_by_css_selector(
-                'div.panel-footer button.btn')
+                '.btn-primary')
             button.click()
             self.current_user = user
-            self.current_project = self.driver.find_element_by_class_name(
-                'context-project').text
+            project_element = self.driver.find_element_by_xpath(
+                self.project_name_xpath)
+            self.current_project = project_element.text
         if self.current_project != project:
-            dropdown_project = self.driver.find_element_by_xpath(
-                '//*[@class="context-project"]//ancestor::ul')
-            dropdown_project.click()
-            selection = dropdown_project.find_element_by_xpath(
+            project_element.click()
+            selection = project_element.find_element_by_xpath(
                 f'.//*[normalize-space()="{project}"]')
             selection.click()
-            self.current_project = self.driver.find_element_by_class_name(
-                'context-project').text
+            widgets.get_and_dismiss_messages(self.driver)
+            self.current_project = self.driver.find_element_by_xpath(
+                self.project_name_xpath).text
 
 
 @pytest.fixture(scope='session')
@@ -127,7 +129,7 @@ def record_video(request, report_dir, xdisplay):
         '-video_size', f'{width}x{height}',
         '-framerate', str(frame_rate),
         '-f', 'x11grab',
-        '-i', f':{display}',
+        '-i', f':{display}',  # noqa: E231
         filepath,
     ]
     fnull = open(os.devnull, 'w')
@@ -148,7 +150,10 @@ def record_video(request, report_dir, xdisplay):
     popen.communicate()
     thread.join()
     if not request.node.stash.get(STASH_FAILED, False):
-        os.remove(filepath)
+        try:
+            os.remove(filepath)
+        except OSError:
+            pass
 
 
 @pytest.fixture(scope='session')
