@@ -34,16 +34,6 @@ def clear_volume_demo(volume_name, openstack_demo):
     )
 
 
-@pytest.fixture
-def clear_volume_admin(volume_name, openstack_admin):
-    yield None
-    wait_for_steady_state_of_volume(openstack_admin, volume_name[0])
-    openstack_admin.delete_volume(
-        volume_name[0],
-        wait=True,
-    )
-
-
 def wait_for_steady_state_of_volume(openstack, volume_name):
     for attempt in range(120):
         if (openstack.block_storage.find_volume(volume_name).status in
@@ -82,8 +72,10 @@ def test_create_empty_volume_demo(login, driver, volume_name, openstack_demo,
     assert openstack_demo.block_storage.find_volume(volume_name) is not None
 
 
-def test_create_volume_from_image_demo(login, driver, volume_name, config,
-                                       clear_volume_demo, openstack_demo):
+def test_create_volume_via_vol_source_image_demo(login, driver,
+                                                 volume_name, config,
+                                                 clear_volume_demo,
+                                                 openstack_demo):
     image_source_name = config.launch_instances.image_name
     volume_name = volume_name[0]
     login('user')
@@ -298,29 +290,34 @@ def test_volumes_pagination_demo(login, driver, volume_name,
         'volumes'
     ))
     driver.get(url)
-    actual_page1_definition = widgets.get_table_definition(driver,
-                                                           sorting=True)
-    assert first_page_definition == actual_page1_definition
+    current_table_status = widgets.get_table_status(driver, "volumes",
+                                                    volume_name[2],
+                                                    sorting=True)
+    assert first_page_definition == current_table_status
     # Turning to next page(page2)
     driver.find_element_by_link_text("Next »").click()
-    actual_page2_definition = widgets.get_table_definition(driver,
-                                                           sorting=True)
-    assert second_page_definition == actual_page2_definition
+    current_table_status = widgets.get_table_status(driver, "volumes",
+                                                    volume_name[1],
+                                                    sorting=True)
+    assert second_page_definition == current_table_status
     # Turning to next page(page3)
     driver.find_element_by_link_text("Next »").click()
-    actual_page3_definition = widgets.get_table_definition(driver,
-                                                           sorting=True)
-    assert third_page_definition == actual_page3_definition
+    current_table_status = widgets.get_table_status(driver, "volumes",
+                                                    volume_name[0],
+                                                    sorting=True)
+    assert third_page_definition == current_table_status
     # Turning back to previous page(page2)
     driver.find_element_by_link_text("« Prev").click()
-    actual_page2_definition = widgets.get_table_definition(driver,
-                                                           sorting=True)
-    assert second_page_definition == actual_page2_definition
+    current_table_status = widgets.get_table_status(driver, "volumes",
+                                                    volume_name[1],
+                                                    sorting=True)
+    assert second_page_definition == current_table_status
     # Turning back to previous page(page1)
     driver.find_element_by_link_text("« Prev").click()
-    actual_page1_definition = widgets.get_table_definition(driver,
-                                                           sorting=True)
-    assert first_page_definition == actual_page1_definition
+    current_table_status = widgets.get_table_status(driver, "volumes",
+                                                    volume_name[2],
+                                                    sorting=True)
+    assert first_page_definition == current_table_status
 
 
 #   Not possible to detach volume from server via OpenstackSDK for
@@ -402,8 +399,9 @@ def test_create_empty_volume_admin(login, driver, volume_name, openstack_admin,
     assert openstack_admin.block_storage.find_volume(volume_name) is not None
 
 
-def test_create_volume_from_image_admin(login, driver, volume_name, config,
-                                        clear_volume_admin, openstack_admin):
+def test_create_volume_via_vol_source_image_admin(login, driver, volume_name,
+                                                  config, clear_volume_admin,
+                                                  openstack_admin):
     image_source_name = config.launch_instances.image_name
     volume_name = volume_name[0]
     login('admin')
@@ -515,26 +513,31 @@ def test_volumes_pagination_admin(login, driver, volume_name,
         'volumes'
     ))
     driver.get(url)
-    actual_page1_definition = widgets.get_table_definition(driver,
-                                                           sorting=True)
-    assert first_page_definition == actual_page1_definition
+    current_table_status = widgets.get_table_status(driver, "volumes",
+                                                    volume_name[2],
+                                                    sorting=True)
+    assert first_page_definition == current_table_status
     # Turning to next page(page2)
     driver.find_element_by_link_text("Next »").click()
-    actual_page2_definition = widgets.get_table_definition(driver,
-                                                           sorting=True)
-    assert second_page_definition == actual_page2_definition
+    current_table_status = widgets.get_table_status(driver, "volumes",
+                                                    volume_name[1],
+                                                    sorting=True)
+    assert second_page_definition == current_table_status
     # Turning to next page(page3)
     driver.find_element_by_link_text("Next »").click()
-    actual_page3_definition = widgets.get_table_definition(driver,
-                                                           sorting=True)
-    assert third_page_definition == actual_page3_definition
+    current_table_status = widgets.get_table_status(driver, "volumes",
+                                                    volume_name[0],
+                                                    sorting=True)
+    assert third_page_definition == current_table_status
     # Turning back to previous page(page2)
     driver.find_element_by_link_text("« Prev").click()
-    actual_page2_definition = widgets.get_table_definition(driver,
-                                                           sorting=True)
-    assert second_page_definition == actual_page2_definition
+    current_table_status = widgets.get_table_status(driver, "volumes",
+                                                    volume_name[1],
+                                                    sorting=True)
+    assert second_page_definition == current_table_status
     # Turning back to previous page(page1)
     driver.find_element_by_link_text("« Prev").click()
-    actual_page1_definition = widgets.get_table_definition(driver,
-                                                           sorting=True)
-    assert first_page_definition == actual_page1_definition
+    current_table_status = widgets.get_table_status(driver, "volumes",
+                                                    volume_name[2],
+                                                    sorting=True)
+    assert first_page_definition == current_table_status
