@@ -18,6 +18,7 @@ from openstack_dashboard.usage.base import ProjectUsage
 from openstack_dashboard.usage.tables import BaseUsageTable
 from openstack_dashboard.usage.tables import GlobalUsageTable
 from openstack_dashboard.usage.tables import ProjectUsageTable
+from openstack_dashboard.usage.views import ProjectUsageView
 from openstack_dashboard.usage.views import UsageView
 
 
@@ -28,5 +29,6 @@ __all__ = [
     'BaseUsageTable',
     'GlobalUsageTable',
     'ProjectUsageTable',
+    'ProjectUsageView',
     'UsageView',
 ]
