@@ -17,10 +17,38 @@ import os
 import pkgutil
 import re
 
+from django.conf import settings
+
 from horizon.utils import file_discovery
+from horizon.utils import functions as utils
+from openstack_dashboard import defaults
 from openstack_dashboard import theme_settings
 
 
+def get_dict_config(name, key):
+    """Get a config value from a dict-type setting.
+
+    If a specified key does not exist in a requested setting,
+    the default value defined in openstack_dashboard.defaults
+    is considered.
+
+    .. warning::
+
+       This function should not be used from horizon plugins
+       as it only checks openstack_dashboard.defaults
+       when accessing default values.
+
+    :param name: Name of a dict-type setting
+    :param key: Key name of the dict-type setting
+    :raises KeyError: Raised if no default value is found for a requested key.
+        (This can happen only for horizon plugin codes.)
+    """
+    config = getattr(settings, name)
+    if key in config:
+        return config[key]
+    return getattr(defaults, name)[key]
+
+
 def import_submodules(module):
     """Import all submodules and make them available in a dict."""
     submodules = {}
@@ -284,6 +312,7 @@ def get_xstatic_dirs(XSTATIC_MODULES, HORIZON_CONFIG):
                 file = 'horizon/lib/' + module.NAME + '/' + file
                 HORIZON_CONFIG['xstatic_lib_files'].append(file)
         except TypeError:
+            # pylint: disable-next=broad-exception-raised
             raise Exception(
                 '%s: Nothing to include because files to include are not '
                 'defined (i.e., None) in BASE_XSTATIC_MODULES list and '
@@ -368,3 +397,13 @@ def find_static_files(
 
     # Add the theme file info to the horizon config for use by template tags
     HORIZON_CONFIG['theme_static_files'] = theme_static_files
+
+
+def get_page_size(request):
+    return utils.get_config_value(request, 'API_RESULT_PAGE_SIZE',
+                                  settings.API_RESULT_PAGE_SIZE)
+
+
+def get_log_length(request):
+    return utils.get_config_value(request, 'INSTANCE_LOG_LENGTH',
+                                  settings.INSTANCE_LOG_LENGTH)
